summaryrefslogtreecommitdiffstats
path: root/include/widgets/textbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/widgets/textbox.h')
-rw-r--r--include/widgets/textbox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/widgets/textbox.h b/include/widgets/textbox.h
index 814202f0..b25b4c02 100644
--- a/include/widgets/textbox.h
+++ b/include/widgets/textbox.h
@@ -168,13 +168,13 @@ void textbox_cursor ( textbox *tb, int pos );
/**
* @param tb Handle to the textbox
* @param pos The position to insert the string at
* @param str The string to insert.
* @param slen The length of the string.
*
* Insert the string str at position pos.
*/
-void textbox_insert ( textbox *tb, const int pos, const char *str, const int slen );
+void textbox_insert ( textbox *tb, const int char_pos, const char *str, const int slen );
/**
* Setup the cached fonts. This is required to do
@@ -168,13 +168,13 @@ void textbox_cursor ( textbox *tb, int pos );
/**
* @param tb Handle to the textbox
- * @param pos The position to insert the string at
+ * @param char_pos The position to insert the string at
* @param str The string to insert.
* @param slen The length of the string.